@@ -3,3 +3,5 @@ __name__ = 'pyspare'
 
 from .deco import deco, deco_dict, deco_entries, deco_matrix, deco_object, deco_str, deco_vector
 from .logger import delog
+from .logger.says.says import Says
+from .logger.says.singleton import says
